@@ -7,7 +7,7 @@ def add_one(number):
     return number + 1
 
 def read_csv(data):
-    API_ENDPOINT = "http://localhost:8080/"
+    API_ENDPOINT = "http://auth.aka.corp.amazon.dev:8080/"
 
     data_collected = {
     'data_collected' : data
